@@ -1,8 +1,20 @@
 import warnings
 
 from pymongo import MongoClient, ReadPreference, uri_parser
-from pymongo.database import _check_name
+from pymongo.common import _UUID_REPRESENTATIONS
 
+try:
+    from pymongo.database_shared import _check_name
+except ImportError:
+    from pymongo.database import _check_name
+
+# DriverInfo was added in PyMongo 3.7.
+try:
+    from pymongo.driver_info import DriverInfo
+except ImportError:
+    DriverInfo = None
+
+import mongoengine
 from mongoengine.pymongo_support import PYMONGO_VERSION
 
 __all__ = [
@@ -124,7 +136,9 @@ def _get_connection_settings(
                 if uri_dict.get(param):
                     conn_settings[param] = uri_dict[param]
 
-            uri_options = uri_dict["options"]
+            uri_options = uri_dict[
+                "options"
+            ]  # uri_options is a _CaseInsensitiveDictionary
             if "replicaset" in uri_options:
                 conn_settings["replicaSet"] = uri_options["replicaset"]
             if "authsource" in uri_options:
@@ -153,12 +167,27 @@ def _get_connection_settings(
                         preference.name.lower() == read_pf_mode
                         or preference.mode == read_pf_mode
                     ):
-                        conn_settings["read_preference"] = preference
+                        ReadPrefClass = preference.__class__
                         break
+
+                if "readpreferencetags" in uri_options:
+                    conn_settings["read_preference"] = ReadPrefClass(
+                        tag_sets=uri_options["readpreferencetags"]
+                    )
+                else:
+                    conn_settings["read_preference"] = ReadPrefClass()
+
             if "authmechanismproperties" in uri_options:
                 conn_settings["authmechanismproperties"] = uri_options[
                     "authmechanismproperties"
                 ]
+            if "uuidrepresentation" in uri_options:
+                REV_UUID_REPRESENTATIONS = {
+                    v: k for k, v in _UUID_REPRESENTATIONS.items()
+                }
+                conn_settings["uuidrepresentation"] = REV_UUID_REPRESENTATIONS[
+                    uri_options["uuidrepresentation"]
+                ]
         else:
             resolved_hosts.append(entity)
     conn_settings["host"] = resolved_hosts
@@ -170,7 +199,7 @@ def _get_connection_settings(
     keys = {
         key.lower() for key in kwargs.keys()
     }  # pymongo options are case insensitive
-    if "uuidrepresentation" not in keys:
+    if "uuidrepresentation" not in keys and "uuidrepresentation" not in conn_settings:
         warnings.warn(
             "No uuidRepresentation is specified! Falling back to "
             "'pythonLegacy' which is the default for pymongo 3.x. "
@@ -320,6 +349,10 @@ def get_connection(alias=DEFAULT_CONNECTION_NAME, reconnect=False):
     # alias and remove the database name and authentication info (we don't
     # care about them at this point).
     conn_settings = _clean_settings(raw_conn_settings)
+    if DriverInfo is not None:
+        conn_settings.setdefault(
+            "driver", DriverInfo("MongoEngine", mongoengine.__version__)
+        )
 
     # Determine if we should use PyMongo's or mongomock's MongoClient.
     if "mongo_client_class" in conn_settings:
